from trytond.model import ModelView, ModelSQL, fields

__all__ = [
    'Ophthalmology',
    'OphthalmologyPatientData']
    
class Ophthalmology(ModelSQL,ModelView):
    'Ophthalmology'
    __name__ = 'gnuhealth.ophthalmology'
    patient = fields.Many2One('gnuhealth.patient', 'Patient', required=True)
    
    # there are two types of charts, a meter chart.. 6/.. val and ft chart.. 200/...
    snells_chart = [
        (None , ''),
        ('6/6' , '6/6'),
        ('6/9' , '6/9'),
        ('6/12' , '6/12'),
        ('6/18' , '6/18'),
        ('6/24' , '6/24'),
        ('6/36' , '6/36'),
        ('6/60' , '6/60'),
        ('5/60' , '5/60'),
        ('4/60' , '4/60'),
        ('3/60' , '3/60'),
        ('2/60' , '2/60'),
        ('1/60' , '1/60'),
        ('1 Meter FC', '1 Meter FC'),
        ('1/2 Meter FC', '1/2 Meter FC'),
        ('HMCF', 'HMCF'),
        ('P/L', 'P/L'),
        ]
    
    # Near vision chart    
    near_vision_chart = [
        (None , ''),
        ('N6' , 'N6'),
        ('N8' , 'N8'),
        ('N12' , 'N12'),
        ('N18' , 'N18' ),
        ('N24' , 'N24' ),
        ('N36' , 'N36' ),
        ('N60' , 'N60' ),
        ]    
    
    #vision test using snells chart
    rdva = fields.Selection(snells_chart, 'RDVA', help="Right Eye Vision of Patient without aid", sort=False)
    ldva = fields.Selection(snells_chart, 'LDVA', help="Left Eye Vision of Patient without aid", sort=False)
        
    #vision test using pinhole accurate manual testing
    rdva_pinhole = fields.Selection(snells_chart, 'RDVA', help="Right Eye Vision of Patient Using Pin Hole", sort=False)
    ldva_pinhole = fields.Selection(snells_chart, 'LDVA', help="Left Eye Vision of Patient Using Pin Hole", sort=False)        
        
    #vison testing with glasses just to assess what the patient sees with his existing aid
    #useful esp with vision syndroms that are not happening because of the lens
    rdva_aid = fields.Selection(snells_chart, 'RDVA AID', help="Right Eye Vision of Patient with glasses or contact lens", sort=False)
    ldva_aid = fields.Selection(snells_chart, 'LDVA AID', help="Left Eye Vision of Patient with glasses or contact lens", sort=False)

    rspherical = fields.Float('Right Eye Spherical')
    lspherical = fields.Float('Left Eye Spherical')
    
    rcylinder = fields.Float('Right Eye Cylinder')
    lcylinder = fields.Float('Left Eye Cylinder')
    
    raxis = fields.Float('Right Eye Axis')
    laxis = fields.Float('Left Eye Axis')

    #near vision testing ie. long sight.. you will get it when u cross 40
    #its also thinning of the lens.. the focus falls behind the retina
    #in case of distant vision ie. short sight.. the focus does not reach retina
    #and is becoming very very common every where esp with the kids
    
    rnv = fields.Selection(near_vision_chart, 'RNV', help="Right Eye Near Vision", sort=False)
    lnv = fields.Selection(near_vision_chart, 'LNV', help="Left Eye Near Vision", sort=False)
    
    #after the above tests the optometrist or doctor comes to a best conclusion
    #best corrected visual acuity
    #the above values are from autorefraction
    #the doctors decision is final
    #and there could be changes in values of cylinder, spherical and axis
    #these values will go into final prescription of glasses or contact lens
    
    #by default these values should be auto populated and should be modifiable by an ophthalmologist
    #todo autopopulate
    
    rbcva_spherical = fields.Float('Right Eye Best Corrected Spherical')
    lbcva_spherical = fields.Float('Left Eye Best Corrected Spherical')
    
    rbcva_cylinder = fields.Float('Right Eye Best Corrected Cylinder')
    lbcva_cylinder = fields.Float('Left Eye Best Corrected Cylinder')
    
    rbcva_axis = fields.Float('Right Eye Best Corrected Axis')
    lbcva_axis = fields.Float('Left Eye Best Corrected Axis')

    
    rbcva = fields.Selection(snells_chart, 'RBCVA', help="Right Eye Best Corrected VA", sort=False)
    lbcva = fields.Selection(snells_chart, 'LBCVA', help="Left Eye Best Corrected VA", sort=False)
    
    rbcva_nv = fields.Selection(near_vision_chart, 'RBCVANV', help="Right Eye Best Corrected Near Vision", sort=False)
    lbcva_nv = fields.Selection(near_vision_chart, 'LBCVANV' , help="Left Eye Best Corrected Near Vision", sort=False)        
        
    #some other tests of the eyes
    #useful for diagnosis of glaucoma a disease that builds up pressure inside the eye and destroy the retina
    #its also called the silent vision stealer
    #intra ocular pressure
    #there are three ways to test iop
    #   SCHIOTZ
    #   NONCONTACT TONOMETRY
	#   GOLDMANN APPLANATION TONOMETRY
	
	#this test is done using a prism fixed on a slit lamp
	#the reading is obtained from the slitlamp knobs
    rschiotz_iop = fields.Float('IOP Right Schiotz ')
    lschiotz_iop = fields.Float('IOP Left Schiotz')
    
    #this is a digital testing, using a machine
    #as it suggest, it does not touch the lens
    #it uses stream of air to get the pressure of the eye
    rnct_iop = fields.Float('IOP Right NCT')
    lnct_iop = fields.Float('IOP Left NCT')
    
    #the traditional way of using the goldmann apparatus
    #it looks like a compass /divider in instrument box,
    rgoldmann_iop = fields.Float('IOP Right Goldmann')
    lgoldmann_iop = fields.Float('IOP Left Goldmann')
    
    
    rsyringing = fields.Selection([  
            (None,""),
            ("False","False"),
            ("True","True"),
           
        ],'RSYR',help="Syringing Right",sort=False)

    lsyringing = fields.Selection([  
            (None,""),
            ("False","False"),
            ("True","True"),
            
        ],'LSYR',help="Syringing Left",sort=False)
        
    #Squint
    rsquint = fields.Selection([  
            (None,""),
            ("False","False"),
            ("True","True"),
            
        ],'RSQUINT',help="Syringing Right",sort=False)

    lsquint = fields.Selection([  
            (None,""),
            ("False","False"),
            ("True","True"),
            
        ],'LSQUINT',help="Syringing Left",sort=False)
        
    
    


#end    
        
class OphthalmologyPatientData(ModelSQL, ModelView):
    __name__ = 'gnuhealth.patient'


